﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace Articles.ZipHandling
{
    public partial class MainWindow : Form
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="MainWindow"/> class.
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Called when user wants to close the window.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        private void OnCmdCloseClick(object sender, EventArgs e)
        {
            this.Close();
        }

        /// <summary>
        /// Called when user wants to select a file to compress.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        private void OnCmdSelectFileToCompress(object sender, EventArgs e)
        {
            if (m_dlgOpenFile.ShowDialog() == DialogResult.OK)
            {
                m_txtFileToCompress.Text = m_dlgOpenFile.FileName;
            }
        }

        /// <summary>
        /// Called when user wants to compress a file.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        private void OnCmdCompressFileClick(object sender, EventArgs e)
        {
            ZipUtility.CompressFile(m_txtFileToCompress.Text);
        }

        /// <summary>
        /// Called when user wants to select a zip file form wich to extract all files from.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        private void OnCmdSourceZip(object sender, EventArgs e)
        {
            if (m_dlgOpenZip.ShowDialog() == DialogResult.OK)
            {
                m_txtSourceZip.Text = m_dlgOpenZip.FileName;
            }
        }

        /// <summary>
        /// Called when user wants to select the target directory.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void OnCmdDestinationDirectoryClick(object sender, EventArgs e)
        {
            if (m_dlgOpenDirectory.ShowDialog() == DialogResult.OK)
            {
                m_txtDestinationDirectory.Text = m_dlgOpenDirectory.SelectedPath;
            }
        }

        /// <summary>
        /// Called when user wants to extract all files within a zip package.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        private void OnCmdExtractFiles(object sender, EventArgs e)
        {
            ZipUtility.ExtractAllFiles(m_txtSourceZip.Text, m_txtDestinationDirectory.Text);
        }

        /// <summary>
        /// Called when user wants to select the file wich should be copied into a zip file.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        private void OnCmdSourceFileClick(object sender, EventArgs e)
        {
            if (m_dlgOpenFile.ShowDialog() == DialogResult.OK)
            {
                m_txtSourceFile.Text = m_dlgOpenFile.FileName;
            }
        }

        /// <summary>
        /// Called when user want so select the target zip-file.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        private void OnCmdTargetZipClick(object sender, EventArgs e)
        {
            if (m_dlgOpenZip.ShowDialog() == DialogResult.OK)
            {
                m_txtTargetZip.Text = m_dlgOpenZip.FileName;
            }
        }

        /// <summary>
        /// Called when user wants to add a file to a zip file.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        private void OnCmdAddToZipClick(object sender, EventArgs e)
        {
            ZipUtility.AddToZip(m_txtSourceFile.Text, m_txtTargetZip.Text);
        }
    }
}
